@@ -6,7 +6,7 @@
  * Date        : 2008-12-10
  * Description : album icon view tool tip
  *
- * SPDX-FileCopyrightText: 2008-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2026 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -31,6 +31,7 @@
 // Local includes
 
 #include "digikam_debug.h"
+#include "digikam_globals.h"
 #include "albummanager.h"
 #include "collectionlocation.h"
 #include "collectionmanager.h"
@@ -86,8 +87,7 @@ QString ToolTipFiller::imageInfoTipContents(const ItemInfo& info)
 
         if (settings->getToolTipsShowFileDate())
         {
-            QDateTime modifiedDate = commonInfo.fileModificationDate;
-            str                    = QLocale().toString(modifiedDate, QLocale::ShortFormat);
+            str                    = asUserDateTime(commonInfo.fileModificationDate);
             tip                   += cnt.cellBeg + i18n("Date:") + cnt.cellMid + str + cnt.cellEnd;
         }
 
@@ -200,7 +200,7 @@ QString ToolTipFiller::imageInfoTipContents(const ItemInfo& info)
             {
                 if (commonInfo.creationDate.isValid())
                 {
-                    str = QLocale().toString(commonInfo.creationDate, QLocale::ShortFormat);
+                    str = asUserDateTime(commonInfo.creationDate);
 
                     if (str.length() > cnt.maxStringLength)
                     {
@@ -340,12 +340,12 @@ QString ToolTipFiller::imageInfoTipContents(const ItemInfo& info)
             {
                 QString durationString;
                 bool ok                = false;
-                const int durationVal  = videoInfo.duration.toInt(&ok);
+                const unsigned int durationVal  = videoInfo.duration.toUInt(&ok);
 
                 if (ok)
                 {
                     unsigned int r, d, h, m, s, f;
-                    r = qAbs(durationVal);
+                    r = durationVal;
                     d = r / 86400000;
                     r = r % 86400000;
                     h = r / 3600000;
@@ -358,7 +358,7 @@ QString ToolTipFiller::imageInfoTipContents(const ItemInfo& info)
                     durationString = QString().asprintf("%d.%02d:%02d:%02d.%03d", d, h, m, s, f);
                 }
 
-                str = videoInfo.duration.isEmpty() ? cnt.unavailable : durationString;
+                str = (videoInfo.duration.isEmpty() || !ok) ? cnt.unavailable : durationString;
 
                 if (str.length() > cnt.maxStringLength)
                 {
