@@ -11,7 +11,7 @@
  * SPDX-FileCopyrightText: 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
  * SPDX-FileCopyrightText:      2013 by Michael G. Hansen <mike at mghansen dot de>
  * SPDX-FileCopyrightText: 2014-2015 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
- * SPDX-FileCopyrightText: 2002-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2002-2026 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -302,6 +302,15 @@ DigikamApp::~DigikamApp()
         qApp->processEvents();
     }
 
+    // Close and delete survey instance.
+
+    if (SurveyWindow::surveyWindowCreated())
+    {
+        SurveyWindow::surveyWindow()->setAttribute(Qt::WA_DeleteOnClose, true);
+        SurveyWindow::surveyWindow()->close();
+        qApp->processEvents();
+    }
+
     // Close and delete Batch Queue Manager instance.
 
     if (QueueMgrWindow::queueManagerWindowCreated())
@@ -858,13 +867,13 @@ void DigikamApp::slotImageSelected(const ItemInfoList& selection, const ItemInfo
                                         numOfImagesInModel - numImagesWithGrouped);
     }
 
-    d->statusLabel->setAdjustedText(statusBarSelectionText);
+    d->statusLabel->setText(statusBarSelectionText);
     d->statusLabel->setToolTip(statusBarSelectionToolTip);
 }
 
 void DigikamApp::slotTrashSelectionChanged(const QString& text)
 {
-    d->statusLabel->setAdjustedText(text);
+    d->statusLabel->setText(text);
     d->statusLabel->setToolTip(text);
 }
 
@@ -1212,6 +1221,7 @@ void DigikamApp::customizedTrashView(bool set)
     d->imagePreviewAction->setEnabled(set);
     d->bqmAction->setEnabled(set);
     d->ltAction->setEnabled(set);
+    d->svAction->setEnabled(set);
     d->ieAction->setEnabled(set);
 
     d->imageSeparationSortOrderAction->setEnabled(set);
