@@ -6,7 +6,7 @@
  * Date        : 2020-11-28
  * Description : ExifTool process stream parser.
  *
- * SPDX-FileCopyrightText: 2020-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2020-2026 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -23,6 +23,8 @@ void ExifToolParser::printExifToolOutput(const QByteArray& stdOut)
     qCDebug(DIGIKAM_METAENGINE_LOG) << "---";
     qCDebug(DIGIKAM_METAENGINE_LOG).noquote() << stdOut;
     qCDebug(DIGIKAM_METAENGINE_LOG) << "---";
+
+    d->error = stdOut.contains(QByteArray("1 files weren't updated due to errors"));
 }
 
 void ExifToolParser::cmdCompleted(const ExifToolProcess::Result& result)
@@ -422,6 +424,7 @@ void ExifToolParser::errorOccurred(const ExifToolProcess::Result& result,
                                       << "exited with error:"
                                       << error;
 
+    d->error       = true;
     d->errorString = description;
 
     Q_EMIT signalExifToolDataAvailable();
